@@ -1,15 +1,13 @@
 import importlib as _importlib
 from spider.param import *
-# from spider import constraints
-# from spider import elements, utils, sampler, evaluator, interface, vehicle_model
-# from spider import motion_planning, path_planning
-# from spider import planner_zoo
-# from spider import RL
+from spider._virtual_import import _virtual_import, _try_import, _try_import_from
+from spider._misc import *
 from spider.teaser import teaser
 
 
 submodules = [
-    'elements', 'utils', 'sampler', 'evaluator', 'interface', 'vehicle_model', 'planner_zoo', 'RL',
+    'elements', 'utils', 'sampler', 'evaluator', 'interface', 'control', 'planner_zoo', 'RL',
+    'data',
     #'teaser', 'param'
 ]
 
@@ -23,6 +21,8 @@ def __dir__():
 def __getattr__(name):
     if name in submodules:
         return _importlib.import_module(f'spider.{name}')
+    elif name =="vehicle_model":
+        return AttributeError("sub module 'spider.vehicle_model' has been moved to 'spider.control.vehicle_model'")
     else:
         try:
             return globals()[name]
