@@ -1,15 +1,18 @@
 from typing import Union
 import numpy as np
-from cvxopt import matrix, solvers
 
+import spider
+try:
+    import cvxopt
+except (ModuleNotFoundError, ImportError) as e:
+    cvxopt = spider._virtual_import("cvxopt", e)
 
 from spider.optimize.BaseOptimizer import BaseOptimizer
 from spider.optimize.common import FrenetTrajOptimParam
-from spider.elements.trajectory import Path, Trajectory, FrenetTrajectory
-from spider.elements import TrackingBoxList, OccupancyGrid2D
+from spider.elements import TrackingBoxList, OccupancyGrid2D, FrenetTrajectory
 from spider.utils.collision.CollisionChecker import BoxCollisionChecker
 from spider.utils.collision.AABB import aabb2vertices
-from spider.vehicle_model import Bicycle
+# from spider.vehicle_model import Bicycle
 
 
 def generate_corridor_bboxes(initial_guess:np.ndarray, bboxes:TrackingBoxList,
@@ -109,7 +112,7 @@ def getConsMat(s0,s_d0,s_dd0,l0,l_d0,l_dd0, target_l_bound,
 
     # 碰撞约束
     # traj = Trajectory(steps=N,dt=dt)
-    # traj.t = [dt*i for i in range(N)]
+    # traj.t = [dt*index for index in range(N)]
     # ss,ls = p.Ms@initial_guess, p.Ml@initial_guess
     # traj.x = ss
     # traj.y = ls
@@ -224,8 +227,10 @@ class FrenetTrajectoryOptimizer(BaseOptimizer):
                                                        traj_sl_array, perception, offset_bound, param=self.param)
 
 
-        Q, f, Aineq, bineq, Aeq, beq = [matrix(i.astype(np.float64)) for i in [Q, f, Aineq, bineq, Aeq, beq]]
-        sol = solvers.qp(Q, f, Aineq, bineq, Aeq, beq)  # kktsolver='ldl', options={'kktreg':1e-9}
+        Q, f, Aineq, bineq, Aeq, beq = [cvxopt.matrix(i.astype(np.float64))
+                                            for i in [Q, f, Aineq, bineq, Aeq, beq]]
+        sol = cvxopt.solvers.qp(Q, f, Aineq, bineq, Aeq, beq, options={'show_progress':False})
+        # kktsolver='ldl', options={'kktreg':1e-9}, options={'show_progress':False}
 
         optim_traj_arr = np.array(sol['x']) # size of [2N, 1] squeeze的过程在下面赋值的时候加了0的列索引
         optim_traj = FrenetTrajectory(traj.steps, traj.dt)
@@ -256,7 +261,7 @@ class FrenetTrajectoryOptimizer(BaseOptimizer):
 if __name__ == '__main__':
     from spider.elements import TrackingBox
     from spider.visualize import draw_polygon
-    from spider.utils.transform.frenet import FrenetCoordinateTransformer
+    from spider.utils.transform.frenet import FrenetTransformer
     import matplotlib.pyplot as plt
 
 
@@ -275,7 +280,7 @@ if __name__ == '__main__':
     xs = np.linspace(0, 80, 80)
     ys = np.linspace(0, 0, 80)
     centerline = np.column_stack((xs, ys))
-    transformer = FrenetCoordinateTransformer(centerline)
+    transformer = FrenetTransformer(centerline)
 
 
     # observation
