@@ -33,8 +33,8 @@ def ego_centric_view(ego_x, ego_y, x_range=(-50.,50.), y_range=(-50.,50.), ax:pl
     ax.set_ylim(y_range[0] + ego_y, y_range[1]+ego_y)
     return ax
 
-def figure(figsize=(6, 6), *args, **kwargs): # figsize=(14, 4)
-    plt.figure(figsize=figsize, *args, **kwargs)
+def figure(num=None, figsize=(6, 6), *args, **kwargs): # figsize=(14, 4)
+    plt.figure(num,figsize=figsize, *args, **kwargs)
     plt.axis('equal')
     plt.tight_layout()
 
